"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

const init = async ({
  databaseName,
  tableName,
  executeStatement,
  escapeId
}) => {
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableNameAsId = escapeId(tableName);
  const threadsTableNameAsId = escapeId(`${tableName}-threads`);
  const aggregateIdAndVersionIndexName = escapeId(`${tableName}-aggregateIdAndVersion`);
  const aggregateIndexName = escapeId(`${tableName}-aggregateId`);
  const aggregateVersionIndexName = escapeId(`${tableName}-aggregateVersion`);
  const typeIndexName = escapeId(`${tableName}-type`);
  const timestampIndexName = escapeId(`${tableName}-timestamp`);
  await executeStatement(`CREATE TABLE ${databaseNameAsId}.${eventsTableNameAsId}(
      "threadId" ${_constants.LONG_NUMBER_SQL_TYPE} NOT NULL,
      "threadCounter" ${_constants.INT8_SQL_TYPE} NOT NULL,
      "timestamp" ${_constants.LONG_NUMBER_SQL_TYPE} NOT NULL,
      "aggregateId" ${_constants.LONG_STRING_SQL_TYPE} NOT NULL,
      "aggregateVersion" ${_constants.LONG_NUMBER_SQL_TYPE} NOT NULL,
      "type" ${_constants.LONG_STRING_SQL_TYPE} NOT NULL,
      "payload" ${_constants.JSON_SQL_TYPE},
      "eventSize" ${_constants.LONG_NUMBER_SQL_TYPE} NOT NULL,
      PRIMARY KEY("threadId", "threadCounter")
    );
    
    CREATE UNIQUE INDEX ${aggregateIdAndVersionIndexName}
    ON ${databaseNameAsId}.${eventsTableNameAsId}
    USING BTREE("aggregateId", "aggregateVersion");
     
    CREATE INDEX ${aggregateIndexName}
    ON ${databaseNameAsId}.${eventsTableNameAsId}
    USING BTREE("aggregateId");
     
    CREATE INDEX ${aggregateVersionIndexName}
    ON ${databaseNameAsId}.${eventsTableNameAsId}
    USING BTREE("aggregateVersion");
     
    CREATE INDEX ${typeIndexName}
    ON ${databaseNameAsId}.${eventsTableNameAsId}
    USING BTREE("type");
     
    CREATE INDEX ${timestampIndexName}
    ON ${databaseNameAsId}.${eventsTableNameAsId}
    USING BTREE("timestamp");
     
    CREATE TABLE ${databaseNameAsId}.${threadsTableNameAsId}(
      "threadId" ${_constants.LONG_NUMBER_SQL_TYPE} NOT NULL,
      "threadCounter" ${_constants.LONG_NUMBER_SQL_TYPE} NOT NULL,
     PRIMARY KEY("threadId")
    );

    INSERT INTO ${databaseNameAsId}.${threadsTableNameAsId}(
      "threadId",
      "threadCounter"
    ) VALUES ${Array.from(new Array(256)).map((_, index) => `(${index}, 0)`).join(',')}
    ;`);
};

var _default = init;
exports.default = _default;
//# sourceMappingURL=init.js.map